TARGET_NODE = "https://api1.aleph.im"
REFERENCE_NODE = "https://api2.aleph.im"
TEST_CHANNEL = "INTEGRATION_TESTS"
